#[non_exhaustive]pub enum ComposeError {
IncompatibleKinds {
left: &'static str,
right: &'static str,
},
IncompatibleMapEntry(String),
Apply(ApplyError),
LengthOverflow,
}Expand description
Errors composing sequential Changes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
IncompatibleKinds
The root Change kinds cannot be composed sequentially.
IncompatibleMapEntry(String)
Two operations on one Map key cannot be composed.
Apply(ApplyError)
Applying a Change to an intermediate replacement failed.
LengthOverflow
The canonical composed Change exceeded a platform length limit.