#[non_exhaustive]pub enum ValueError {
NonFiniteFloat,
DuplicateKey(String),
LengthOverflow,
}Expand description
Errors produced while constructing canonical Values and typed Changes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NonFiniteFloat
A Float or floating-point attribute was NaN or infinite.
DuplicateKey(String)
A Map, Attrs, AttrPatch, or MapChange input repeated a key.
LengthOverflow
A logical length or allocation capacity exceeded the platform limit.