invert

Function invert 

pub fn invert(change: &Change, base: &Value) -> Result<Change, InvertError>
Builds the inverse of change relative to its original Snapshot.

A Change does not contain old values, so inversion requires base.